$Title   Illustrative Analysis of Competitiveness Issues in Unilateral Carbon Tax Policies

set dummy	/0, 1, 2, 5, 10, 15, 20, exempt/; 

*	Include default scenario settings
*	Assign dataset

$set dataset 3x8-EIS

*	Capital mobility

$if not set rsk $set rsk yes

*	Armington elasticity (D v M): 1

$if not set sigmadm $set sigmadm 4

*	Coal supply elasticity:

$if not set etacoal $set etacoal 0.5

*	Oil supply elasticity: 

$if not set etacrude $set etacrude 1

*	International oil price: flexible fixed

$set oilprice flexible


set mkt /cru, oil, gas, coa, ele, oth, eis, cgds, fd/;

*	Include model dimensions
set i(mkt),r(*),f(*);

$if exist %dataset%.gdx $gdxin %dataset%.gdx

*	Load model sets for sectors (i), regions (r), and factors (f)
$load i r f

set	t		Time periods	/ 2005, 2010, 2015, 2020, 2025, 2030 /;
set     fe(i)           Fossil fuels    /oil, gas, coa/;


alias (i,j), (r,s), (r,rr);

scalar	rsk	Region specific capital;  rsk = %rsk%;

set     cgd(i) /cgds/;

set     d	Classes of demand for which import shares are differentiated / 
        G       Public, 
        C       Private Consumption,
        I       Intermediate input /;

parameter
        ty(i,r)         Output tax

        ti(j,i,r)       Intermediate input tax
	tid(j,i,r)	Intermediate input tax - domestic
	tii(j,i,r)	Intermediate input tax - imports

        tf(f,i,r)       Factor tax

        tx(i,s,r)       Export tax rate (defined on a net basis)
        tm(i,s,r)       Import tariff rate

        tg(i,r)         Tax rates on government demand
	tgd(i,r)	Tax rate on governmnet demand - domestic
	tgi(i,r)	Tax rate on governmnet demand - imports

        tp(i,r)         Tax rate on private demand
	tpd(i,r)	Tax rate on private demand - domestic
	tpi(i,r)	Tax rate on private demand - imports

        vafm(j,i,r)     Aggregate intermediate inputs
        vafmd(j,i,r)    Aggregate intermediate inputs - domestic
        vafmi(j,i,r)    Aggregate intermediate inputs - imports


        vfm(f,i,r)      Value of factor inputs (net of tax)
        vxmd(i,r,s)     Value of commodity trade (fob - net export tax)

        vtwr(i,r,s)     Transport services
	dvtwr(i,j,r,s)	Differentiated transport serives	

        vst(i,r)        Value of international transport sales

        vdgm(i,r)       Government demand (domestic)
        vigm(i,r)       Government demand (imported)

        vdpm(i,r)       Aggregate private demands (domestic)
        vipm(i,r)       Aggregate private demands (domestic)

	eind(i,j,r)	Volume of energy inputs by firms (MTOE),
	efd(i,r)	Volume of energy inputs by households (MTOE)
*	IEO baseline data:
	ieocarbon	Emission growth index (2001=1)
	ieogdp		GDP growth index (2001=1)
	ieopop		Population (in millions)
	ieocrude	Crude oil production growth index (2001=1)
	ieoprice	Crude oil price index (2001=1);	
	
*	Load model data:

$load   ty=rto tf=rtf tpd=rtpd tpi=rtpi tgd=rtgd tgi=rtgi tid=rtfd tii=rtfi tx=rtxs tm=rtms
$load	vafmd=vdfm vafmi=vifm vfm vxmd vst vdgm vigm vdpm vipm dvtwr=vtwr
$load	eind=evf efd=evh ieocarbon ieogdp ieopop ieoprice ieocrude


*	Do scaling of data:

*	Conversion of monetary data into 10 of billions $US
scalar convert /0.1/;

*	Conversion factor from MTOE (default: GTAP6) into EJ
scalar	mtoetej		MTOE per EJ  /0.041868/;

eind(fe,j,r)	= mtoetej*eind(fe,j,r); 
efd(fe,r)	= mtoetej*efd(fe,r); 

vafmd(j,i,r)   = convert*vafmd(j,i,r);
vafmi(j,i,r)   = convert*vafmi(j,i,r);
vfm(f,i,r)     = convert*vfm(f,i,r);
vxmd(i,r,s)    = convert*vxmd(i,r,s);
dvtwr(j,i,r,s) = convert*dvtwr(j,i,r,s);
vst(i,r)       = convert*vst(i,r);
vdgm(i,r)      = convert*vdgm(i,r);
vigm(i,r)      = convert*vigm(i,r);
vdpm(i,r)      = convert*vdpm(i,r);
vipm(i,r)      = convert*vipm(i,r);

vafm(i,j,r) = vafmi(i,j,r) + vafmd(i,j,r);
vtwr(i,s,r) = sum(j, dvtwr(j,i,s,r));

ti(j,i,r)$(vafmd(j,i,r) + vafmi(j,i,r))  = (tid(j,i,r)*vafmd(j,i,r) + tii(j,i,r)*vafmi(j,i,r))/(vafmd(j,i,r) + vafmi(j,i,r));
tg(i,r)$(vigm(i,r)+vdgm(i,r))            = (tgd(i,r)*vdgm(i,r) + tgi(i,r)*vigm(i,r))/(vigm(i,r)+vdgm(i,r));
tp(i,r)$(vipm(i,r)+vdpm(i,r))		 = (tpd(i,r)*vdpm(i,r) + tpi(i,r)*vipm(i,r))/(vipm(i,r)+vdpm(i,r));

tx(i,s,r)   = - tx(i,s,r);


scalar  sigmadm		Armington elasticity (D versus M) /%sigmadm%/,
        sigmamm		Armington elasticity (M versus M)
        globalemit	Global emissions target /0/
        fixedoilp	Fixed world oil price /0/;

sigmamm = 2*sigmadm;

*	OPEC may hold crude oil world prices fixed in the policy counterfactual
*	through supply side reationing
set     opec(i,r); opec(i,r) = no;
$if %oilprice%==fixed fixedoilp=1;

*	Subset of regions which might offset leakage in case
*	of subglobal action
set offset(r); offset(r) = no;


*       Declare and assign intermediate variables:
parameter
        ty0(i,r)        Output tax
        ti0(j,i,r)      Intermediate input tax
        tf0(f,i,r)      Factor tax
        tx0(i,s,*)      Export tax rate (defined on a net basis)
        tm0(i,s,r)      Import tariff rate
        tg0(i,r)        Tax rates on government demand
        tp0(i,r)        Tax rate on private demand

        pi0(j,i,r)      Reference price for intermediate inputs
	pf0(f,i,r)	Reference price for factor inputs

        vim(i,r)        Total value of imports (gross tariff)
        vxm(i,r)        Value of export (net excise tax)
        vdm(i,r)        Value of domestic output (net excise tax)
        vdfm(i,r)       Aggregate intermediate demand (domestic)
        vifm(i,r)       Aggregate intermediate demand (imported)

        vom(i,r)        Aggregate output value (gross of tax)
        vgm(i,r)        Public expenditures
        vpm(i,r)        Private expenditures
        vg(r)           Total value of public expenditure
        vp(r)           Total value of private expenditure
        vt              Value of trade markups
        capflow(*)      Net capital flows

        evoa(f,r)       Value of factor income;

ty0(i,r)   = ty(i,r);
ti0(j,i,r) = ti(j,i,r);
tf0(f,i,r) = tf(f,i,r);
tx0(i,s,r) = tx(i,s,r);
tm0(i,s,r) = tm(i,s,r);
tg0(i,r)   = tg(i,r);
tp0(i,r)   = tp(i,r);
pi0(j,i,r) = 1 + ti0(j,i,r);
pf0(f,i,r) = 1 + tf0(f,i,r);

vxm(i,r)  = max(0, round( sum(s, vxmd(i,r,s)), 6));
vim(i,r)  = max(0, round(sum(s,(vxmd(i,s,r)*(1+tx(i,s,r))+vtwr(i,s,r))*(1+tm(i,s,r))), 6));

vdm(i,r)  = max(0, round(( sum(j, vafm(j,i,r)*(1+ti(j,i,r))) 
                       + sum(f,  vfm(f,i,r)*(1+tf(f,i,r)))) / (1-ty(i,r)) - vxm(i,r), 6));

vdfm(i,r) = max(0, round(vdm(i,r) - vst(i,r)  - vdgm(i,r) - vdpm(i,r) - vdm(i,r)$cgd(i),6));
vifm(i,r) = max(0, round(vim(i,r) - vipm(i,r) - vigm(i,r), 6));

vom(i,r)  = vdm(i,r) + vxm(i,r);
vgm(i,r)  = vigm(i,r)+vdgm(i,r);
vpm(i,r)  = vipm(i,r)+vdpm(i,r);
vg(r)	  = sum(i, vgm(i,r) * (1 + tg(i,r)));
vp(r)	  = sum(i, vpm(i,r) * (1 + tp(i,r)));
vt	  = sum((i,r), vst(i,r));

evoa(f,r) = sum(i, vfm(f,i,r));

capflow(r) = vp(r) + vg(r) + vdm("cgds",r)
	     - sum(f, evoa(f,r)) 
	     - sum(i, ty(i,r)   * vom(i,r))
	     - sum((i,j), ti(j,i,r) * vafm(j,i,r))
	     - sum((i,f), tf(f,i,r) * vfm(f,i,r))
	     - sum((i,s), tx(i,r,s)  * vxmd(i,r,s))
	     - sum((i,s), tm(i,s,r)  * (vxmd(i,s,r)*(1+tx(i,s,r)) + vtwr(i,s,r)) )
	     - sum(i, tg(i,r)*vgm(i,r))
	     - sum(i, tp(i,r)*vpm(i,r));

capflow("checksum") = sum(r, capflow(r));
display capflow;


*	Further model-specific assignments

set     nr(i,r)         Non-resource production
        ele(i)          Electricity			/ele/,
        nele(i)		Non-electric energy inputs	/gas,oil,coa/,
	lqd(i)		Liquid energy inputs		/gas,oil/,		
        xe(i)           Exhaustible energy		/cru,gas,coa/
        cru(i)          Crude oil			/cru/,
        gas(i)          Natural gas			/gas/,
        coa(i)          Coal				/coa/,
        wmkt(i)         Homogeneous energy goods	/cru, coa /
        ymkt(i,r)       Sectors with output markets;



set 	e(i) /  gas     Natural gas works
                ele     Electricity and heat 
                oil     Refined oil products
                coa     Coal transformation
                cru     Crude oil /;

nr(i,r) = yes$(vom(i,r)$(not xe(i)));


parameter       cecphys(*)      Carbon emission coefficients for physical units 
                                /coa 0.025, gas 0.014, oil 0.020 /

parameter
        a0(i,r)         Armington supply
        m0(i,r)         Aggregate import supply
        d0(i,r)         Aggregate domestic supply

        c0(i,r)         Final demand by commodity
        tc(i,r)         Tax rate on final demand
        ct0(r)          Total final demand
        pc0(i,r)        Reference price for final demand

        ld0(i,r)        Base year labor demand by sector
        kd0(i,r)        Base year capital earnings by sector
        
        pmx0(i,s,r)     Reference price of imports
        pmt0(i,s,r)     Reference price of transport services

        tmoil(r)        Crude oil import tariff
        txoil(r)        Crude oil export tariff

        tshare(i,r)     Transport cost share
        ex0(i,r)        Homogeneous exports
        em0(i,r)        Homogeneous imports
        et0(i,r)        Transport cost on homogeneous imports
        txe(i,r)        Export tax rate
        tme(i,r)        Import tax rate
        vex0(i,r)       Value of homogeneous exports
        vem0(i,r)       Value of homogeneous imports
        mktadj(i,r)     Market adjustment accomodating homogeneous trade

        rd0(i,r)        Resource inputs for fossil fuel production
        prref(i,r)      Reference price of energy-supply resource

        ffsupply(i,r)   Fossil fuel supply

        carbcoef(j,*,r) Carbon coefficients
        carblim(*)      Carbon emission limit

        isub(r)         Intra-fuel substitution in final demand
        esub(r)         Elasticity between VA and energy
	etrn(r)		Elasticity of transformation
        e_vae(r)        Elasticity of substitution in the VA production nest
        e_elec(i,r)     Elasticity of substituion between electricity and non-electric gas and oil
        e_c_go(i,r)     Elasticity between coal and the oil-gas aggregate 
        e_g_o(i,r)      Elasticity of substitution between oil and gas in production

        esub_es(i,r)    Elasticity of substitution in energy production
        thetar(i,r)     Value share of resource inputs in fossil supply

        eta(xe)         Elasticity of supply 

        esubdm(i,r)     Armington elasticity - domestic vesus imports
        esubmm(i,r)     Armington elasticity - intra-imports

        gdp(r)          GDP index for future projection
        pytarget        Target baseline prices for oil - coal - gas;

a0(i,r) = vipm(i,r) + vdpm(i,r) + vigm(i,r) + vdgm(i,r) + vifm(i,r) + vdfm(i,r);
d0(i,r) = vdpm(i,r) + vdgm(i,r) + vdfm(i,r);
m0(i,r) = vipm(i,r) + vigm(i,r) + vifm(i,r);

c0(i,r)		= vpm(i,r) + vgm(i,r);
tc(i,r)$c0(i,r) = (tp(i,r)*vpm(i,r) + tg(i,r)*vgm(i,r)) / c0(i,r);
ct0(r)		= sum(i, c0(i,r)*(1+tc(i,r)));
pc0(i,r)	= 1 + tc(i,r);

ld0(i,r) = vfm("lab",i,r);
kd0(i,r) = vfm("cap",i,r);
        
pmx0(i,s,r) = (1 + tm(i,s,r))*(1+tx(i,s,r));
pmt0(i,s,r) = 1 + tm(i,s,r);

*       Convert WMKT goods into homogeneous goods:

vdm(wmkt,r) = vdm(wmkt,r) + vxm(wmkt,r);
vxm(wmkt,r) = 0;
vim(wmkt,r) = 0;
m0(wmkt,r)  = 0;
em0(wmkt,r) = max(0, +sum(s, vxmd(wmkt,s,r)*(1+tx(wmkt,s,r)))
                     -sum(s, vxmd(wmkt,r,s)*(1+tx(wmkt,r,s))));
ex0(wmkt,r) = max(0, -sum(s, vxmd(wmkt,s,r)*(1+tx(wmkt,s,r)))
                     +sum(s, vxmd(wmkt,r,s)*(1+tx(wmkt,r,s))));
txe(wmkt,r)$ex0(wmkt,r) = round( sum(s, vxmd(wmkt,r,s)*tx(wmkt,r,s)) /
                                 sum(s, vxmd(wmkt,r,s)), 2);
vex0(wmkt,r) = ex0(wmkt,r) / (1 + txe(wmkt,r));
tshare(wmkt,r)$em0(wmkt,r) = sum(s, vtwr(wmkt,s,r)) /
				sum((s,rr)$em0(wmkt,rr), vtwr(wmkt,s,rr));
et0(wmkt,r)$em0(wmkt,r)    = tshare(wmkt,r) * sum((s,rr), vtwr(wmkt,s,rr));
tme(wmkt,r)$em0(wmkt,r)    = round(sum(s, (vxmd(wmkt,s,r)*(1+tx(wmkt,s,r))+vtwr(wmkt,s,r))*tm(wmkt,s,r)) /
				 sum(s, (vxmd(wmkt,s,r)*(1+tx(wmkt,s,r))+vtwr(wmkt,s,r)) ), 2);
vem0(wmkt,r)		   = (em0(wmkt,r) + et0(wmkt,r)) * (1 + tme(wmkt,r));
mktadj(wmkt,r)$a0(wmkt,r)  = (a0(wmkt,r) - vdm(wmkt,r) - vem0(wmkt,r) + vex0(wmkt,r))
                                / a0(wmkt,r);
display mktadj;

*       Finally, convert all inputs into the Armington nest into the py market:

d0(wmkt,r) = a0(wmkt,r);

*       Base year carbon emissions:

carbcoef(fe,"fd",r)	= cecphys(fe) * efd(fe,r);
carbcoef(fe,i,r)        = cecphys(fe) * eind(fe,i,r);
carblim(r)		= sum(fe, carbcoef(fe,"fd",r) + sum(i, carbcoef(fe,i,r)));
carblim("world")	= sum(r, carblim(r));
display carbcoef, carblim;

parameter       carbonbmk       Benchmark carbon emissions -- here 2001 (IEA)
                carbon90        1990 carbon emissions (approximation based on IEO);

carbonbmk(r) = sum(fe, carbcoef(fe,"fd",r) + sum(i, carbcoef(fe,i,r)));
carbonbmk("world") = sum(r, carbonbmk(r));

*       Assign elasticities of substitution:
isub(r)     = 1.0;
esub(r)     = 0.5;
etrn(r)	    = 2;
e_vae(r)    = 1.0;
e_elec(i,r) = 0.1;
e_c_go(i,r) = 0.5;
e_g_o(i,r)  = 1.0;

eta("cru")  = %etacrude%;
eta("gas")  = 1.0;
eta("coa")  = %etacoal%;

esubdm(i,r)  = sigmadm;
esubmm(i,r)  = sigmamm;
esubdm(fe,r) = 0.5;

*       Set GDP index initially at benchmark level for benchmark replication:
gdp(r) = 1;

*       Establish resource inputs for resource supply:
*	Note:	If initial capital taxes apply we move these into
*		gross capital earnings
kd0(xe,r) = kd0(xe,r)*(1+ tf0("cap",xe,r));
tf("cap",xe,r)=0; tf0("cap",xe,r)=0; pf0("cap",xe,r) = 1;
rd0(xe,r)$vom(xe,r)	 = min(kd0(xe,r), 0.5 * (vdm(xe,r) + vxm(xe,r)) * (1-ty(xe,r))) ;
kd0(xe,r)$vom(xe,r)	 = round(kd0(xe,r) - rd0(xe,r), 6);
esub_es(xe,r)	         = 0;
prref(xe,r)	         = 1;


*       Identify markets which are open, including those for 
*       crude oil which may be imported but not produced:

ymkt(i,r)		 = yes$vom(i,r);
ymkt(wmkt,r)$em0(wmkt,r) = yes;

*       Recompute capital flows in order to account for changes in 
*       crude oil trade flows etc:

capflow(r) = vp(r) + vg(r) + vdm("cgds",r)
        - evoa("lab",r)
        - sum(i, kd0(i,r))
        - sum(xe, rd0(xe,r))
        - sum(wmkt,mktadj(wmkt,r)*a0(wmkt,r))
        - sum(i, ty(i,r)   * vom(i,r))
        - sum((i,j), ti(j,i,r) * vafm(j,i,r))
        - sum((i,f), tf(f,i,r) * vfm(f,i,r))
        - sum((i,s)$(not wmkt(i)), tx(i,r,s)  * vxmd(i,r,s))
        - sum((i,s)$(not wmkt(i)), tm(i,s,r)  * (vxmd(i,s,r)*(1+tx(i,s,r)) + vtwr(i,s,r)))
        - sum(wmkt, txe(wmkt,r)*vex0(wmkt,r) + tme(wmkt,r)*(em0(wmkt,r)+et0(wmkt,r)))
        - sum(i, tg(i,r)*vgm(i,r))
        - sum(i, tp(i,r)*vpm(i,r));

capflow("checksum") = sum(r, capflow(r));
display capflow;


*       Generate some echo-prints:

parameter
        CCOEF           Carbon coefficients
        VSHARE          Energy value shares for non-energy sectors
        CARBINV         CO2 inventories (IEA)-- mton
        CARBINT         Sectoral CO2 intensities --kg per $output ;


parameter energy  energy use;
energy(e,r,i) = round(eind(e,i,r), 1);
energy(e,r,"fd") = round(efd(e,r), 1);
option energy:1:1:1;
display energy;

vshare(r,i)$(vom(i,r) and (not e(i)))   = round( 100 * sum(e, vafm(e,i,r)*(1+ti(e,i,r))) / vom(i,r), 1);
ccoef(r,nele)				= cecphys(nele);
carbinv(r,"ind_nele")			= 1000 * sum((e,i)$(not ele(i)), ccoef(r,e)*eind(e,i,r));
carbinv(r,"fd_nele")			= 1000 * sum(e, ccoef(r,e)*efd(e,r));
ccoef(r,ele)				= sum(nele, cecphys(nele) * eind(nele,ele,r))/
						(sum(i, eind(ele,i,r)) + efd(ele,r));
carbinv(r,"electric")			= 1000*sum((e,ele), ccoef(r,e)*eind(e,ele,r));
carbinv(r,"total")			= 1000*sum(e, ccoef(r,e)*(sum(i$(not ele(i)), eind(e,i,r))+efd(e,r)) );
carbinv(r,"ind_total")			= 1000 * sum((e,i)$(not ele(i)), ccoef(r,e)*eind(e,i,r));
carbinv(r,"fd_total")			= 1000 * sum(e, ccoef(r,e)*efd(e,r));
carbinv(r,"kg/$")			= round(carbinv(r,"total")/(10*sum((f,i), vfm(f,i,r))), 1);

set jrep /total,ind_total, fd_total, ind_nele, fd_nele, electric/;
set irep(i) /ele/;  irep("oil") = yes; irep(i)$(not e(i)) = yes;

carbinv("total",jrep)		= sum(r, carbinv(r,jrep));
carbint(r,ele)$vom(ele,r)	= round(100*sum(nele, cecphys(nele) * eind(nele,ele,r))/vom(ele,r),1);
carbint(r,irep)$(not ele(irep))= round(100*sum(e, ccoef(r,e)*eind(e,irep,r))/vom(irep,r), 1);
option vshare:1, carbinv:1, carbint:1;
display vshare, carbinv, carbint;

parameter pm0(i,r); pm0(i,r) = 1;


*	For fossil fuel sectors without benchmark capital inputs
*	we may re-shift some labor inputs in order to define resource rents  
loop((xe,r)$(vom(xe,r) and (not (rd0(xe,r)))),
     if (ld0(xe,r),	
	  rd0(xe,r)      = 0.5*ld0(xe,r); 
	  tf("lab",xe,r) = (tf0("lab",xe,r)*ld0(xe,r))/(0.5*ld0(xe,r));		
	  evoa("lab",r)  = evoa("lab",r) - 0.5*ld0(xe,r);   
	  ld0(xe,r)      = 0.5*ld0(xe,r);
	  pf0("lab",i,r) = 1 + tf("lab",i,r);
	 );  
     );	

*	Fossil fuel sectors which have no value-added inputs are shut down
*	- associated outputs and intermediate inputs are shifted into endowments

parameter ff_adjust(*,*,*,*)	Adjustment parameter;
ff_adjust("py","xxx",xe,r)=0; ff_adjust("px","xxx",xe,r)=0; ff_adjust("pa",j,xe,r)= 0;	ff_adjust("tax","xxx","xxx",r)=0;

loop((xe,r)$(not (kd0(xe,r)+ld0(xe,r))),
	ff_adjust("py","xxx",xe,r)	= vdm(xe,r);	  
	ff_adjust("px","xxx",xe,r)	= vxm(xe,r);	  
	ff_adjust("pa",j,xe,r)		= vafm(j,xe,r);	
	ff_adjust("tax","xxx",xe,r)	= (vxm(xe,r)+ vdm(xe,r))*ty(xe,r) + sum(j, vafm(j,xe,r)* ti(j,xe,r) );	

	vom(xe,r)   = 0;
	vdm(xe,r)   = 0;	  
	vxm(xe,r)   = 0;  	  
	vafm(j,xe,r)= 0;
    );

ffsupply(xe,r)       = 1$rd0(xe,r);

set eg(i)	/cru, oil, gas, coa, ele/

parameter	cO2perunit(i,mkt,r)	Per unit carbon coefficient;
co2perunit(i,mkt,r)		= 0;
co2perunit(fe,"fd",r)$c0(fe,r)	= carbcoef(fe,"fd",r)/c0(fe,r); 
co2perunit(fe,i,r)$vafm(fe,i,r)	= carbcoef(fe,i,r)/vafm(fe,i,r); 


set	exempt(r)	Flag for exemptions;
set	ctax(r)		Flag for active carbon tax regime; 
set	exempted(mkt)	Flag for exempted sectors;
scalar	multi		Multiplier for differentiated carbon tax	/1/;

ctax(r) = no; exempt(r) = no;
exempted(mkt) = no; exempted("eis") = yes; exempted("oil") = yes;

$ontext
$model:gtap

$sectors:
        c(r)			! Private consumption
        y(i,r)$vom(i,r)		! Output
        a(i,r)$a0(i,r)		! Armington aggregation of domestic and imports
        m(i,r)$vim(i,r)		! Imports
        em(wmkt,r)$em0(wmkt,r)	! Energy imports by region
        ex(wmkt,r)$ex0(wmkt,r)	! Energy exports by region
        yt			! Transport 
	es(eg,mkt,r)		! Energy supply 

$commodities:
        pc(r)			! Final demand
        pe(i)$wmkt(i)		! International market energy price
        py(i,r)$ymkt(i,r)	! Output price price
        pa(i,r)$a0(i,r)		! Armington composite price
        pm(i,r)$vim(i,r)	! Import price
        pl(r)			! Wage rate
        pr(xe,r)$rd0(xe,r)	! Energy resource
        rk(r)$rsk		! Return to capital (region-specific capital)
	rkw$(not rsk)		! Return to capital (global capital)
        pt			! Transport services
	px(i,r)$vxm(i,r)	! Export market price
	pe_eg(eg,mkt,r)		! Price for energy including potential carbon value
	pcarb(r)$ctax(r)	! Carbon tax rate




$consumers:
        ra(r)				! Representative agent

$auxiliary:
        rs(i,r)$rd0(i,r)			! Resource supply index
        rslvl(i)$wmkt(i)			! Resource supply for international resources
	scale(r)$(exempt(r) or offset(r))	! Carbon budget adjustment multiplier

$report:
        v:edf(fe,r)$c0(fe,r)			i:pe_eg(fe,"fd",r)	prod:es(fe,"fd",r)
        v:ed(fe,i,r)$vafm(fe,i,r)		i:pe_eg(fe,i,r)		prod:es(fe,i,r)
	v:k_d(i,r)$(not rsk)			i:rkw			prod:y(i,r)	
	v:import(i,s,r)$vxmd(i,s,r)		i:px(i,s)		prod:m(i,r)
	v:domest(i,r)$(a0(i,r) and d0(i,r))	i:py(i,r)		prod:a(i,r)
	v:trans_neg(i,s,r)$vxmd(i,s,r)		i:pt#(s)		prod:m(i,r)
	v:trans_eg(wmkt,r)$em0(wmkt,r)		i:pt			prod:em(wmkt,r)
	v:py_yt(i,r)				i:py(i,r)		prod:yt


*       Final demand:

$prod:c(r)  s:esub(r) c:1 e:isub(r) 
        o:pc(r)			q:ct0(r)
        i:pa(i,r)$(not eg(i))   q:c0(i,r)      p:pc0(i,r) a:ra(r) t:tc(i,r)		c:
	i:pe_eg(fe,"fd",r)	q:c0(fe,r)     p:pc0(fe,r) a:ra(r) t:tc(fe,r)		e: 	
	i:pe_eg("ele","fd",r)	q:c0("ele",r)  p:pc0("ele",r) a:ra(r) t:tc("ele",r)	c: 	
	i:pe_eg("cru","fd",r)	q:c0("cru",r)  p:pc0("cru",r) a:ra(r) t:tc("cru",r)	c: 	


*       Non-fossil fuel production (includes electricity and refining):

$prod:y(i,r)$nr(i,r)  t:etrn(r) s:0  vae(s):esub(r)  va(vae):e_vae(r) 
+                       e(vae):e_elec(i,r)  nel(e):e_c_go(i,r) lqd(nel):e_g_o(i,r) 
        o:py(i,r)		q:vdm(i,r)  a:ra(r) t:ty(i,r) 
        o:px(i,r)		q:vxm(i,r)  a:ra(r) t:ty(i,r) 
	i:pa(j,r)$(not eg(j))   q:vafm(j,i,r) p:pi0(j,i,r)       a:ra(r) t:ti(j,i,r) 
        i:pe_eg(eg,i,r)	        q:vafm(eg,i,r) p:pi0(eg,i,r)	 a:ra(r) t:ti(eg,i,r) 
+			e:$ele(eg)	nel:$coa(eg)	lqd:$lqd(eg)
        i:pl(r)			q:ld0(i,r) p:pf0("lab",i,r)      a:ra(r) t:tf("lab",i,r)   va:
        i:rk(r)$rsk		q:kd0(i,r) p:pf0("cap",i,r)      a:ra(r) t:tf("cap",i,r)   va:
        i:rkw$(not rsk)		q:kd0(i,r) p:pf0("cap",i,r)      a:ra(r) t:tf("cap",i,r)   va:

*       Fossil fuel production activity (crude, gas and coal):

$prod:y(xe,r)$vom(xe,r)  t:etrn(r)	s:esub_es(xe,r)  id:0 
        o:py(xe,r)		q:vdm(xe,r)				a:ra(r) t:ty(xe,r) 
	o:px(xe,r)		q:vxm(xe,r)				a:ra(r) t:ty(xe,r) 
        i:pa(j,r)$(not eg(j))   q:vafm(j,xe,r)	p:pi0(j,xe,r)		a:ra(r) t:ti(j,xe,r)	 id:
        i:pe_eg(eg,xe,r)	q:vafm(eg,xe,r)	p:pi0(eg,xe,r)		a:ra(r) t:ti(eg,xe,r)	 id: 
        i:pl(r)			q:ld0(xe,r)	p:pf0("lab",xe,r)	a:ra(r) t:tf("lab",xe,r) id:
        i:rk(r)$rsk		q:kd0(xe,r)	p:pf0("cap",xe,r)	a:ra(r) t:tf("cap",xe,r) id:
        i:rkw$(not rsk)		q:kd0(xe,r)	p:pf0("cap",xe,r)	a:ra(r) t:tf("cap",xe,r) id:
        i:pr(xe,r)		q:rd0(xe,r)     p:prref(xe,r)           

*       Energy supply to demand segments:

$prod:es(eg,mkt,r)$exempted(mkt)			s:0
        o:pe_eg(eg,mkt,r)				q:1
        i:pa(eg,r)					q:1
        i:pcarb(r)$(ctax(r) and (not exempt(r)))	q:cO2perunit(eg,mkt,r)     a:ra(r) t:(1/multi - 1)


$prod:es(eg,mkt,r)$(not exempted(mkt))		s:0
        o:pe_eg(eg,mkt,r)			q:1
        i:pa(eg,r)				q:1
	i:pcarb(r)$ctax(r)			q:cO2perunit(eg,mkt,r)     

*       Armington aggregation over domestic versus imports:

$prod:a(i,r)$a0(i,r)  s:esubdm(i,r) 
        o:pa(i,r)       q:a0(i,r)
        i:py(i,r)       q:d0(i,r)  
        i:pm(i,r)       q:m0(i,r)  p:pm0(i,r)

$prod:m(i,r)$vim(i,r) s:esubmm(i,r) s.tl:0
        o:pm(i,r)       q:vim(i,r)
        i:px(i,s)$vxmd(i,s,r)      q:vxmd(i,s,r)  p:pmx0(i,s,r) s.tl:
+               a:ra(s) t:tx(i,s,r)     a:ra(r) t:(tm(i,s,r)*(1+tx(i,s,r)))
        i:pt#(s)        q:vtwr(i,s,r)  p:pmt0(i,s,r) s.tl: 
+               a:ra(r) t:tm(i,s,r)

*	Homogenous energy goods:	
$prod:em(wmkt,r)$em0(wmkt,r)
        o:py(wmkt,r)    q:vem0(wmkt,r)
        i:pe(wmkt)	q:em0(wmkt,r) a:ra(r) t:tme(wmkt,r)
        i:pt		q:et0(wmkt,r) a:ra(r) t:tme(wmkt,r)

$prod:ex(wmkt,r)$ex0(wmkt,r)
        o:pe(wmkt)	q:ex0(wmkt,r)
        i:py(wmkt,r)	q:vex0(wmkt,r)  a:ra(r) t:txe(wmkt,r)  


*       International transport services (Cobb-Douglas):

$prod:yt  s:0
        o:pt            q:(sum((i,r), vst(i,r)))
        i:py(i,r)       q:vst(i,r)

*       Final demand over consumption, savings and government 
*       services (Cobb-Douglas):

$demand:ra(r) 
        d:pc(r)
        e:py(cgd,r)             q:(-vdm(cgd,r)*gdp(r))
        e:py(wmkt,r)            q:(mktadj(wmkt,r)*a0(wmkt,r)*gdp(r))
        e:pc("OEC")             q:(capflow(r)*gdp(r))
        e:pl(r)                 q:(evoa("lab",r)*gdp(r))
        e:rk(r)$rsk		q:(sum(i,kd0(i,r))*gdp(r))
        e:rkw$(not rsk)		q:(sum(i,kd0(i,r))*gdp(r))
        e:pr(xe,r)              q:(rd0(xe,r) *ffsupply(xe, r))  r:rs(xe,r)
*	Adjustment for fossil fuel sectors that are inactive (due to missing value-added inputs)
	e:py(xe,r)		q:ff_adjust("py","xxx",xe,r)
	e:px(xe,r)		q:ff_adjust("px","xxx",xe,r)
	e:pa(j,r)		q:(-sum(xe, ff_adjust("pa",j,xe,r)))
	e:pc(r)			q:(sum(xe, ff_adjust("tax","xxx",xe,r)))
*	Carbon tax revenues
        e:pcarb(r)$ctax(r)	q:carblim(r)	r:scale(r)$(exempt(r) or offset(r))	

*       In the BAU calculation we adjust resource endowments of coal
*       and natural gas to calibrate the model to given target price:

$constraint:rs(i,r)$rd0(i,r)
          ( pytarget(i,"OEC") * pc("OEC") - pe(i) )$opec(i,r)
        + ( pytarget(i,r)*pc(r) - py(i,r) )$(not wmkt(i))
        + ( rs(i,r) - rslvl(i)            )$(wmkt(i) and (not opec(i,r))) =e= 0;

*       Multiplicative scaling of resources achieves a given world price:

$constraint:rslvl(wmkt)
        pytarget(wmkt,"OEC") * pc("OEC") =e= pe(wmkt);

*       The abatement target is multiplicatively scaled among
*       restricting countries to achieve a given world target:

$constraint:scale(r)$(exempt(r) or offset(r))
	carblim(r)$(exempt(r) and (not offset(r))) + globalemit$(offset(r))
		=e= sum((eg,mkt), es(eg,mkt,r)*cO2perunit(eg,mkt,r))$(exempt(r) and (not offset(r)))
		     + 	sum((eg,mkt,rr), es(eg,mkt,rr)*cO2perunit(eg,mkt,rr))$(offset(r));


*.$constraint:scale(r)$(exempt(r) or offset(r))
*.	carblim(r)$(exempt(r)$ (not offset(r))) + globalemit$(offset(r))
*.		=e= sum((eg,mkt), es(eg,mkt,r)*cO2perunit(eg,mkt,r))$(exempt(r)$(not offset(r)))
*.		     + 	sum((eg,mkt,rr), es(eg,mkt,rr)*cO2perunit(eg,mkt,rr))$(offset(r));
*.(carblim(r)$(not offset(r)) + globalemit$(offset(r)))
*.		=e= (sum((eg,mkt), es(eg,mkt,r)*cO2perunit(eg,mkt,r))$((not offset(r)))
*.		     + 	sum((eg,mkt,rr), es(eg,mkt,rr)*cO2perunit(eg,mkt,rr))$(offset(r)));

$offtext
$sysinclude mpsgeset gtap

ex.l(wmkt,r)$(not ex0(wmkt,r)) = 0;
em.l(wmkt,r)$(not em0(wmkt,r)) = 0;

pcarb.l(r)		= 1.e-5;
rs.l(i,r)$rd0(i,r)	= 1;
rslvl.l(wmkt)		= 1;
pytarget(xe,r)		= 1;
scale.lo(r)		= 0;
scale.l(r)		= 1;


es.l(eg,i,r)	= vafm(eg,i,r);
es.l(eg,"fd",r)	= c0(eg,r);	


*       Replicate the 1995 calibrated benchmark -- the deviation should be 
*       on the order of 1e-5:

gtap.iterlim = 0;
$include gtap.gen
solve gtap using mcp;
display "BaU check -- this deviation should be less than 1e-4:", gtap.objval;
abort$((abs(gtap.objval) ge 1e-4))"Model does not calibrate"; 

*       Now fix resource supplies and recalibrate elasticities to
*       specified price elasticities:
rs.fx(i,r)$rd0(i,r)	= rs.l(i,r);
rslvl.fx(wmkt)		= rslvl.l(wmkt);

*	Compute the value share of the specfic-resource along the baseline path:
thetar(xe,r)$rd0(xe,r) = (pr.l(xe,r)*rs.l(xe,r)*rd0(xe,r)*ffsupply(xe,r)) / 
	  ( y.l(xe,r)*(pl.l(r)*ld0(xe,r)*(1+tf("lab",xe,r)) 
	    + (rk.l(r)$rsk + rkw.l$(not rsk))*kd0(xe,r)*(1+tf("cap",xe,r))+ sum(j, pa.l(j,r)*(1+ti(j,xe,r))*vafm(j,xe,r))) 
	    + pr.l(xe,r)*rs.l(xe,r)*rd0(xe,r)*ffsupply(xe,r));
display thetar;

*	Compute the elasticity of substiution which is then consistent with
*	the specified elasticity of fossil fuel supply:

esub_es(xe,r)$((1-thetar(xe,r))$rd0(xe,r)) = thetar(xe,r) * eta(xe) / (1-thetar(xe,r));

*	Finally, specify the reference price of the resource input:  
prref(xe,r)$rd0(xe,r) = [thetar(xe,r)*( sum(j, vafm(j,xe,r)*pi0(j,xe,r)) + ld0(xe,r)*pf0("lab",xe,r) + kd0(xe,r)*pf0("cap",xe,r) )]/
				[(1-thetar(xe,r))*rd0(xe,r)];


parameter       coalm   Coal imports (% market);
coalm(r,"CF")$em0("coa",r)   = 100 * em.l("coa",r)*vem0("coa",r)/(a.l("coa",r)*d0("coa",r));
coalm(r,"Base")$em0("coa",r) = 100 * vem0("coa",r)/d0("coa",r);


*	Recalibrate trade functions so we can alter the trade elasticities
*	while holding the BAU value constant:

vtwr(i,s,r)$vxmd(i,s,r) = vtwr(i,s,r) * import.l(i,s,r) / (vxmd(i,s,r)*m.l(i,r));
vxmd(i,s,r)		= import.l(i,s,r) / m.l(i,r);
pmx0(i,s,r)$vxmd(i,s,r) = px.l(i,s) * (1 + tx(i,s,r))*(1+tm(i,s,r));
pmt0(i,s,r)$vtwr(i,s,r) = pt.l * (1+tm(i,s,r));

d0(i,r)$(a.l(i,r) and a0(i,r) and d0(i,r)) = domest.l(i,r) / a.l(i,r);
m0(i,r)$(a.l(i,r) and a0(i,r) and m0(i,r)) = m.l(i,r) * vim(i,r) / a.l(i,r);
pm0(i,r) = pm.l(i,r)/py.l(i,r);

*	We can now change the elasticity without affecting
*	the baseline growth path:

esubdm(i,r)$(not e(i))  = sigmadm;
esubmm(i,r)$(not e(i))  = sigmamm;

*       Check the recalibration:

gtap.iterlim = 0;
$include gtap.gen
solve gtap using mcp;
abort$((abs(gtap.objval) ge 1e-4))"Model does not re-calibrate"; 

*	Save BaU values
parameter	bauequil	Business-as-usual equilibrium level values;
alias(r,rr); alias(s,ss);

bauequil("c",r,"xxx","xxx")	  = c.l(r);      
bauequil("y",i,r,"xxx")		  = y.l(i,r);
bauequil("a",i,r,"xxx")		  = a.l(i,r);
bauequil("m",i,r,"xxx")		  = m.l(i,r);
bauequil("em",wmkt,r,"xxx")	  = em.l(wmkt,r);
bauequil("ex",wmkt,r,"xxx")	  = ex.l(wmkt,r);
bauequil("yt","xxx","xxx","xxx")  = yt.l;        
bauequil("rs",i,r,"xxx")	  = rs.l(i,r);        
bauequil("rslvl",i,"%region%","xxx")  = rslvl.l(i);        
bauequil("pc",r,"xxx","xxx")	  = pc.l(r);  
bauequil("pe",wmkt,"xxx","xxx")   = pe.l(wmkt);
bauequil("py",i,r,"xxx")	  = py.l(i,r);
bauequil("px",i,r,"xxx")	  = px.l(i,r);
bauequil("pa",i,r,"xxx")	  = pa.l(i,r);
bauequil("pm",i,r,"xxx")	  = pm.l(i,r);
bauequil("pl",r,"xxx","xxx")	  = pl.l(r);  
bauequil("pr",xe,r,"xxx")	  = pr.l(xe,r);
bauequil("rk",r,"xxx","xxx")      = rk.l(r)$rsk + rkw.l$(not rsk);  
bauequil("pt","xxx","xxx","xxx")  = pt.l;     
bauequil("import",i,s,r)	  = import.l(i,s,r);
bauequil("rca",i,r,"xxx")$(sum(s, vxmd(i,s,r)))  = (sum(s, import.l(i,r,s)*px.l(i,r))/sum(s, import.l(i,s,r)*px.l(i,s)))/
								(sum((s,j), import.l(j,r,s)*px.l(j,r))/sum((s,j), import.l(j,s,r)*px.l(j,s)));
bauequil("rwa",i,r,"xxx")$(sum(s, vxmd(i,r,s))) = (sum(s, import.l(i,r,s)*px.l(i,r))/sum((s,j),import.l(j,r,s)*px.l(j,r)))/ 
			(sum((rr,ss),import.l(i,rr,ss)*px.l(i,rr))/sum((rr,ss,j),import.l(j,rr,ss)*px.l(j,rr)));
bauequil("trans_neg",i,s,r)       = trans_neg.l(i,s,r);
bauequil("trans_eg",wmkt,r,"xxx") = trans_eg.l(wmkt,r);
bauequil("py_yt",i,r,"xxx")       = py_yt.l(i,r);
bauequil("k_trd",r,"xxx","xxx")$(not rsk)   = (sum(i,kd0(i,r))*gdp(r)) - sum(i, k_d.l(i,r));

gtap.iterlim = 8000;

gtap.workspace = 20;

*=============================== Scenario definition ================================================

*	Policy scenarios

set	sc	Core scenarios 
	/
	Offset_No	Unilateral abatement action without leakage offset,
	Offset_Yes	Unilateral abatement action with leakage offset
	/,
	
	Offset_No(sc)	/Offset_No/,
	Offset_Yes(sc)	/Offset_Yes/,
	runsc(sc)	/Offset_No, Offset_Yes/;

*	Implement policy counterfactuals with different degrees of tax differentiation
*	ranging from a uniform taxes (multi = 1) via a ratio of 20 (multi=20) to full exemptions  
*	Perform simultaneouly sensitivity analysis w.r.t. to the unilateral emission reduction target

set targets	Emission reduction targets	/ 0, 5, 10, 15, 20, 25, 30/;

set steps	Tax differential		/1, 2, 5, 10, 15, 20, exempt/; 

parameter value(targets)  / 0 0, 5 5, 10 10, 15 15, 20 20, 25 25, 30 30/;
parameter multiple(steps) /1 1, 2 2, 5 5, 10 10, 15 15, 20 20, exempt 100 /;

scalar cutback;

parameter	report	Report parameter;
scalar		solved	Flag for indicating model solution status /0/;
set		items	report items /solved, welfare, ToT1,ToT2, eis_out, oil_out, oth_out, 
				     leakage, eis_rca, oil_rca, oth_rca, eis_rwa, oil_rwa, oth_rwa, ctax1, ctax2/; 

*	Unilateral abatement by Europe with
*	tax differentiation including exemptions

ctax("eur")	  = yes; 

gtap.solvelink = 2;
loop(sc$runsc(sc), 

	if (Offset_no(sc),
	  offset("eur")	  = no;  
	  display offset;
	);

	if (Offset_Yes(sc),
	  offset("eur")	  = yes;  
	  display offset;
	);

	loop(targets$(ord(targets) gt 1),
	  cutback          = value(targets)/100;
	  carblim("eur")   = (1-cutback)*carbonbmk("eur");
	  globalemit	   = sum(r$(not ctax(r)), carbonbmk(r)) + sum(r$ctax(r), carblim(r));
	  exempt("eur")	   = no;	
	  loop(steps,
	    if ( (ord(steps) lt card(steps)),
		   multi=multiple(steps);
	    else
		   exempt("eur") = 1;
	    );

$include gtap.gen
solve gtap using mcp;

	    report(sc,targets,steps,"solved")	= eps + 1$((gtap.solvestat eq 1) and  (gtap.modelstat eq 1)); 

	    report(sc,targets,steps,"welfare")	= round( 100*(c.l("eur")/bauequil("c","eur","xxx","xxx") - 1),2);

*	Terms of trade (ToT) is here defined as the ratio relative value of exports 
*	to the relative value of imports. As ToT is positive (negative), there is an 
*	improvement (deterioration) in the terms of trade.

	    report(sc,targets,steps,"ToT1")		=  round(100*((sum( (i,s), import.l(i,"eur",s)*px.l(i,"eur") )/
		         sum((i,s), bauequil("import",i,"eur",s)*bauequil("px",i,"eur","xxx"))) 
		       /(sum((i,s), import.l(i,s,"eur")*px.l(i,s))/
		         sum((i,s), bauequil("import",i,s,"eur")*bauequil("px",i,s,"xxx"))) - 1), 1); 

	    report(sc,targets,steps,"ToT2")		=  round(100*((sum( (i,s), bauequil("import",i,"eur",s)*px.l(i,"eur") )/
		         sum((i,s), bauequil("import",i,"eur",s)*bauequil("px",i,"eur","xxx"))) 
		       /(sum((i,s), bauequil("import",i,s,"eur")*px.l(i,s))/
		         sum((i,s), bauequil("import",i,s,"eur")*bauequil("px",i,s,"xxx"))) - 1), 1); 

	    report(sc,targets,steps,"eis_out")	= 100 * (y.l("eis","eur") /bauequil("y","eis","eur","xxx") - 1);
	    report(sc,targets,steps,"oil_out")	= 100 * (y.l("oil","eur") /bauequil("y","oil","eur","xxx") - 1);
	    report(sc,targets,steps,"ele_out")	= 100 * (y.l("ele","eur") /bauequil("y","ele","eur","xxx") - 1);
	    report(sc,targets,steps,"oth_out")	= 100 * (y.l("oth","eur") /bauequil("y","oth","eur","xxx") - 1);

	    report(sc,targets,steps,"leakage")$cutback		    = 100 * (
		sum(r$(not ctax(r)),  sum((eg,mkt), es.l(eg,mkt,r)*cO2perunit(eg,mkt,r)) - carbonbmk(r))
		/ sum(r$ctax(r), max(0,carbonbmk(r)-  sum((eg,mkt), es.l(eg,mkt,r)*cO2perunit(eg,mkt,r)))) );	

	    report(sc,targets,steps,"eis_rca")$bauequil("rca","eis","eur","xxx")   = round(100 * (
		((sum(s, import.l("eis","eur",s)*px.l("eis","eur"))/sum(s, import.l("eis",s,"eur")*px.l("eis",s)))/
		(sum((s,j), import.l(j,"eur",s)*px.l(j,"eur"))/sum((s,j), import.l(j,s,"eur")*px.l(j,s))))
			/bauequil("rca","eis","eur","xxx") - 1), 3);

	    report(sc,targets,steps,"oil_rca")$bauequil("rca","oil","eur","xxx")	= round(100 * (
		((sum(s, import.l("oil","eur",s)*px.l("oil","eur"))/sum(s, import.l("oil",s,"eur")*px.l("oil",s)))/
		(sum((s,j), import.l(j,"eur",s)*px.l(j,"eur"))/sum((s,j), import.l(j,s,"eur")*px.l(j,s))))
			/bauequil("rca","oil","eur","xxx") - 1), 3);

	    report(sc,targets,steps,"ele_rca")$bauequil("rca","ele","eur","xxx")	= round(100 * (
		((sum(s, import.l("ele","eur",s)*px.l("ele","eur"))/sum(s, import.l("ele",s,"eur")*px.l("ele",s)))/
		(sum((s,j), import.l(j,"eur",s)*px.l(j,"eur"))/sum((s,j), import.l(j,s,"eur")*px.l(j,s))))
			/bauequil("rca","ele","eur","xxx") - 1), 3);


	    report(sc,targets,steps,"oth_rca")$bauequil("rca","oth","eur","xxx")	= round(100 * (
		((sum(s, import.l("oth","eur",s)*px.l("oth","eur"))/sum(s, import.l("oth",s,"eur")*px.l("oth",s)))/
		(sum((s,j), import.l(j,"eur",s)*px.l(j,"eur"))/sum((s,j), import.l(j,s,"eur")*px.l(j,s))))
			/bauequil("rca","oth","eur","xxx") - 1), 3);

	    report(sc,targets,steps,"eis_rwa")$bauequil("rwa","eis","eur","xxx") = round(100* (
		((sum(s, import.l("eis","eur",s)*px.l("eis","eur"))/sum((s,j),import.l(j,"eur",s)*px.l(j,"eur")))/ 
		(sum((rr,ss),import.l("eis",rr,ss)*px.l("eis",rr))/sum((rr,ss,j),import.l(j,rr,ss)*px.l(j,rr))))
		/bauequil("rwa","eis","eur","xxx") -1), 3); 

	    report(sc,targets,steps,"oil_rwa")$bauequil("rwa","oil","eur","xxx") = round(100* (
		((sum(s, import.l("oil","eur",s)*px.l("oil","eur"))/sum((s,j),import.l(j,"eur",s)*px.l(j,"eur")))/ 
		(sum((rr,ss),import.l("oil",rr,ss)*px.l("oil",rr))/sum((rr,ss,j),import.l(j,rr,ss)*px.l(j,rr))))
			/bauequil("rwa","oil","eur","xxx") -1), 3); 

	    report(sc,targets,steps,"ele_rwa")$bauequil("rwa","ele","eur","xxx") = round(100* (	
		((sum(s, import.l("ele","eur",s)*px.l("ele","eur"))/sum((s,j),import.l(j,"eur",s)*px.l(j,"eur")))/ 
		(sum((rr,ss),import.l("ele",rr,ss)*px.l("ele",rr))/sum((rr,ss,j),import.l(j,rr,ss)*px.l(j,rr))))
			/bauequil("rwa","ele","eur","xxx") -1), 3); 


	    report(sc,targets,steps,"oth_rwa")$bauequil("rwa","oth","eur","xxx") = round(100* (
		((sum(s, import.l("oth","eur",s)*px.l("oth","eur"))/sum((s,j),import.l(j,"eur",s)*px.l(j,"eur")))/ 
		(sum((rr,ss),import.l("oth",rr,ss)*px.l("oth",rr))/sum((rr,ss,j),import.l(j,rr,ss)*px.l(j,rr))))
			/bauequil("rwa","oth","eur","xxx") -1), 3); 

	    report(sc,targets,steps,"ctax2")		       = 10*pcarb.l("eur")/pc.l("eur");
	    report(sc,targets,steps,"ctax1")$(not exempt("eur"))   = 10/multi*pcarb.l("eur")/pc.l("eur");
	    report(sc,targets,steps,"ctax1")$(exempt("eur"))       = eps;
	display report;
	);
));
display report;

